#ifndef NT2_INCLUDE_FUNCTIONS_INTERLEAVE_ODD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_INTERLEAVE_ODD_HPP_INCLUDED

#include <nt2/swar/include/functions/interleave_odd.hpp>

#endif
